import React, { useEffect, useState } from 'react';
import { Button } from 'primereact/button';
import { Card } from 'primereact/card';
import { useNavigate } from 'react-router-dom';
import { Auth, Session } from '../services';
import { BackendReturnStatus } from '../types';

export const Login: React.FC = () => {
  const [loading, setLoading] = useState<boolean>(true);
  const navigate = useNavigate();

  // check if the known bearer token is still valid
  useEffect(() => {
    Auth.tokenIsValid().then((status) => {
      if (status !== BackendReturnStatus.Ok) {
        Session.reset();
        setLoading(false);
      } else {
        navigate('/overview');
      }
    });
  // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  if (loading) return <></>;

  const footer = (
    <span>
      <Button
        label='Login with VATSIM'
        className='p-button'
        onClick={() => Auth.triggerLoginFlow()}
      />
    </span>
  );

  return (
    <>
      <div className='card min-h-screen'>
        <div className='flex flex-wrap align-items-center justify-content-center card-container min-h-screen'>
          <Card
            title='Arrival MANager'
            className='login-card text-center surface-200'
            style={{ width: '25rem' }}
            footer={footer}>
          </Card>
        </div>
      </div>
    </>
  );
};
