import { createContext, Dispatch, SetStateAction, useEffect, useState } from 'react';
import { Auth } from '../services';
import { BackendReturnStatus, IAuthState } from '../types';

const InitialAuthState: IAuthState = {
  valid: false,
  user: {
    vatsimId: '',
    fullName: '',
    radarScopeKey: '',
    administrator: false,
    airportConfigurationAccess: [],
  },
};

const AuthContext = createContext<{
  auth: IAuthState;
  setAuth: Dispatch<SetStateAction<IAuthState>>;
  reloadAuth: () => void;
  resetAuth: () => void;
}>({ auth: InitialAuthState, setAuth: () => {}, reloadAuth: () => {}, resetAuth: () => {} });

export const AuthProvider = ({ children }: { children: any }) => {
  const [auth, setAuth] = useState<IAuthState>(InitialAuthState);

  const reloadAuth = () => {
    Auth.user().then((response) => {
      if (response.status === BackendReturnStatus.Ok) {
        setAuth({ valid: true, user: response.user });
      } else {
        setAuth(InitialAuthState);
      }
    });
  };

  const resetAuth = () => setAuth(InitialAuthState);

  useEffect(() => {
    reloadAuth();
  // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <>
      <AuthContext.Provider value={{ auth, setAuth, reloadAuth, resetAuth }}>
        {children}
      </AuthContext.Provider>
    </>
  );
};

export default AuthContext;
