import React, { Dispatch, SetStateAction, useEffect, useState } from 'react';
import { Auth, System } from '../services';
import { BackendReturnStatus } from '../types';

const TimeContext = React.createContext<{
  offset: number;
  setOffset: Dispatch<SetStateAction<number>>;
}>({ offset: 0, setOffset: () => 0 });

export const TimeProvider = ({ children }: { children: any }) => {
  const [offset, setOffset] = useState<number>(0);

  useEffect(() => {
    const estimateTimeOffset = async () => {
      System.timestamp().then((response) => {
        if (response.status === BackendReturnStatus.Unauthorized) {
          Auth.triggerLoginFlow();
          // TODO reload user data in auth
          // TODO store current URL and get back after login
        } else if (response.status === BackendReturnStatus.Ok) {
          // calculate the time offset (not accurate) between the server and the client to show "correct" times
          const clientTimeUtc = new Date().getTime()
          const serverTimeUtc = response.timestamp;
          setOffset(serverTimeUtc - clientTimeUtc);
        }
      })
    }

    estimateTimeOffset();
    const interval = setInterval(estimateTimeOffset, 30000);
    return () => {
      clearInterval(interval);
    }
  // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <>
      <TimeContext.Provider value={{ offset, setOffset }}>
        {children}
      </TimeContext.Provider>
    </>
  );
};

export default TimeContext;
