import axios from 'axios';
import { Configuration } from './configuration';
import { Session } from './session';
import { BackendReturnStatus, TimestampBackend } from '../types';

export class System {
  static async timestamp(): Promise<TimestampBackend> {
    const token = Session.bearerToken();
    if (!token) {
      return {
        status: BackendReturnStatus.Unauthorized,
        timestamp: 0,
      };
    }

    return axios
      .get<number>(`${Configuration.resourceServer}/system/timestamp`, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
      })
      .then((response) => {
        return {
          status: BackendReturnStatus.Ok,
          timestamp: response.data,
        };
      })
      .catch((err) => {
        return {
          status: err.response.status === 401 ? BackendReturnStatus.Unauthorized : BackendReturnStatus.Failure,
          timestamp: 0,
        };
      });
  }
}
